@@ -482,7 +482,7 @@ class EmailSend(object):
 @ezfuc.retry(2)
 def getIP():
     try:
-        res = requests.get("http://192.168.18.8:39111/?key=123",timeout=3).json()
+        res = requests.get("http://192.168.18.8:39111/123",timeout=3).json()
     except:
         return None
 
